@@ -1,6 +1,6 @@
 package Elastic::Model::TypeMap::Base;
 {
-  $Elastic::Model::TypeMap::Base::VERSION = '0.21';
+  $Elastic::Model::TypeMap::Base::VERSION = '0.22';
 }
 
 use strict;
@@ -423,11 +423,6 @@ sub _fixup_mapping {
     delete $defn->{analyzer}
         if $defn->{index_analyzer} && $defn->{search_analyzer};
 
-    # make 'undef' a false value for boolean fields
-    $defn->{null_value} = 0
-        if $defn->{type} eq 'boolean'
-        and not exists $defn->{null_value};
-
     return $defn;
 }
 
@@ -501,7 +496,7 @@ Elastic::Model::TypeMap::Base - A base class for all TypeMaps
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
